@@ -33,6 +33,7 @@ def _colored(txt, color="green"):
         "green": 32,
         "red": 31,
         "yellow": 33,
+        "grey": 30,
     }
 
     return "\033[1;%sm%s\033[0m" % (cm[color], txt)
@@ -144,6 +145,7 @@ def add(args):
     sk = args.sk
     alias = args.alias or ns
     e, n = _get_current(config)
+
     for k, v in config["endpoints"][e]["namespaces"].items():
         if (v["alias"] == alias or k == alias) and k != ns:
             print("Alias %s has been taken by %s, choose another one." % (_colored(alias, "red"), k))
@@ -159,8 +161,16 @@ def add(args):
         print(
             "Add new namespace %s(%s) to %s.\n" %
             (_colored(ns, "green"), _colored(alias, "green"), _colored(e, "yellow")))
+
     write_config(config)
 
+    try:
+        print("Try to access the namespace...")
+        c = ACMClient(endpoint=e, namespace=n, ak=ak, sk=sk)
+        c.list(1, 1)
+        print("Namespace access succeed.")
+    except:
+        print(_colored("\nWarning: Access test failed, there may be mistakes in configuration.\n", "grey"))
 
 def use(args):
     config = read_config()
@@ -479,10 +489,10 @@ def arg_parse():
     parser_bind.add_argument("endpoint", help="ACM endpoint to bind.")
     parser_bind.add_argument("--tls", action="store_true", default=False, help="to use tls connection.")
 
-    parser_bind.add_argument("-u", dest="namespace", help='namespace to add.')
+    parser_bind.add_argument("-u", dest="namespace", help='namespace id to add.')
     parser_bind.add_argument("-a", dest="ak", default=None, help='AccessKey of this namespace.')
     parser_bind.add_argument("-s", dest="sk", help='SecretKey of this namespace.')
-    parser_bind.add_argument("-n", dest="alias", help="alias of the endpoint.")
+    parser_bind.add_argument("-n", dest="alias", help="alias of the namespace.")
     parser_bind.set_defaults(func=bind)
 
     # add
@@ -491,10 +501,10 @@ def arg_parse():
                                                    "update if namespace is already added.",
                                        epilog="Example: acm add ea61357b-d417-460c-92e4-032677dd8153 "
                                               "-s 'GLff***xcao=' -a 654b43******e9750 -n foo")
-    parser_add.add_argument("namespace", default=None, help='namespace to add.')
+    parser_add.add_argument("namespace", default=None, help='namespace id to add.')
     parser_add.add_argument("-a", dest="ak", default=None, help='AccessKey of this namespace.')
     parser_add.add_argument("-s", dest="sk", help='SecretKey of this namespace.')
-    parser_add.add_argument("-n", dest="alias", help="alias of the endpoint.")
+    parser_add.add_argument("-n", dest="alias", help="alias of the namespace.")
     parser_add.set_defaults(func=add)
 
     # use
@@ -502,10 +512,7 @@ def arg_parse():
                                        description="Switch to a namespace of current endpoint, "
                                                    "if namespace is absent, add one.",
                                        epilog="Example: acm use foo")
-    parser_use.add_argument("namespace", help='namespace or alias to use.')
-    parser_use.add_argument("-a", dest="ak", default=None, help='AccessKey of this namespace.')
-    parser_use.add_argument("-s", dest="sk", help='SecretKey of this namespace.')
-    parser_use.add_argument("-n", dest="alias", help="alias of the endpoint.")
+    parser_use.add_argument("namespace", help='namespace id or alias to use.')
     parser_use.set_defaults(func=use)
 
     # current
@@ -522,7 +529,7 @@ def arg_parse():
     parser_list = subparsers.add_parser("list", help="get list of dataIds", description="Get list of dataIds.")
     parser_list.add_argument("-g", dest="group", default=None, help='group of the dataId.')
     parser_list.add_argument("-p", dest="prefix", default=None, help='prefix of dataId.')
-    parser_list.add_argument("-n", dest="namespace", default=None, help='name or alias of specified namespace.')
+    parser_list.add_argument("-n", dest="namespace", default=None, help='id or alias of specified namespace.')
     parser_list.set_defaults(func=list_conf)
 
     # pull
@@ -533,7 +540,7 @@ def arg_parse():
                                              'if group is specified, file will be store under an subdir of group name.')
     parser_pull.add_argument("-f", dest="file", default=None, help="file to store the content, create one if absent.")
     parser_pull.add_argument("-o", action="store_true", dest="stdout", default=False, help="only print on console.")
-    parser_pull.add_argument("-n", dest="namespace", default=None, help="name or alias of specified namespace.")
+    parser_pull.add_argument("-n", dest="namespace", default=None, help="id or alias of specified namespace.")
     parser_pull.set_defaults(func=pull)
 
     # push
@@ -544,14 +551,14 @@ def arg_parse():
                                           "if parent dir is attached, it will be use as group.")
     parser_push.add_argument("-d", dest="data_id", default=None, help='dataId to store the content, '
                                                                       'use group"/"dataId to specify group.')
-    parser_push.add_argument("-n", dest="namespace", default=None, help='name or alias of specified namespace.')
+    parser_push.add_argument("-n", dest="namespace", default=None, help='id or alias of specified namespace.')
     parser_push.set_defaults(func=push)
 
     # export
     parser_export = subparsers.add_parser("export", help="export dataIds to local files",
                                           description="Export dataIds of specified namespace to local files.")
     parser_export.add_argument("-d", dest="dir", default=None, help='export destination dir.')
-    parser_export.add_argument("-n", dest="namespace", default=None, help='name or alias of specified namespace.')
+    parser_export.add_argument("-n", dest="namespace", default=None, help='id or alias of specified namespace.')
     parser_export.add_argument("--delete", action="store_true", default=False,
                                help="delete the file not exist in ACM server (hidden files startswith . are igonred).")
     parser_export.add_argument("--force", action="store_true", default=False, help="run and delete silently.")
@@ -561,7 +568,7 @@ def arg_parse():
     parser_import = subparsers.add_parser("import", help="import files to ACM server",
                                           description="Import files to ACM server, using specified namespace.")
     parser_import.add_argument("-d", dest="dir", default=None, help='import source dir.')
-    parser_import.add_argument("-n", dest="namespace", default=None, help='name or alias of specified namespace.')
+    parser_import.add_argument("-n", dest="namespace", default=None, help='id or alias of specified namespace.')
     parser_import.add_argument("--delete", action="store_true", default=False,
                                help="delete the dataId not exist locally.")
     parser_import.add_argument("--force", action="store_true", default=False, help="run and delete silently.")
